summaryrefslogtreecommitdiffstats
path: root/net/url_request/url_request_http_job.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/url_request/url_request_http_job.h')
-rw-r--r--net/url_request/url_request_http_job.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/net/url_request/url_request_http_job.h b/net/url_request/url_request_http_job.h
index 48c155d..a74d398 100644
--- a/net/url_request/url_request_http_job.h
+++ b/net/url_request/url_request_http_job.h
@@ -74,8 +74,8 @@ class URLRequestHttpJob : public URLRequestJob {
std::string AssembleRequestCookies();
void FetchResponseCookies();
- // Process the X-Force-TLS header, if one exists.
- void ProcessForceTLSHeader();
+ // Process the Strict-Transport-Security header, if one exists.
+ void ProcessStrictTransportSecurityHeader();
void OnStartCompleted(int result);
void OnReadCompleted(int result);